-- custom bouncing ("out back") easing
local myEasing = ZO_GenerateCubicBezierEase(.05, 1.85, .75, .75)
 
function timelineAnimation(control)
    local isValidAnchor, point, relativeTo, relativePoint, offsetX, offsetY = control:GetAnchor()
 
    local timeline = ANIMATION_MANAGER:CreateTimeline()
 
    -- scale to 100% using our custom easing
    local popup = timeline:InsertAnimation(ANIMATION_SCALE, control)
    popup:SetScaleValues(0, 1)
    popup:SetDuration(500)
    popup:SetEasingFunction(myEasing)
 
    -- animate opacity from 0% to 100%
    local fadeIn = timeline:InsertAnimation(ANIMATION_ALPHA, control)
    fadeIn:SetAlphaValues(0, 1)
    fadeIn:SetDuration(150)
    fadeIn:SetEasingFunction(ZO_EaseOutQuadratic)
 
    -- begin fading out after 2 seconds
    local fadeOut = timeline:InsertAnimation(ANIMATION_ALPHA, control, AGT.saved.OnScreen.displayTicks*1000)
    fadeOut:SetAlphaValues(1, 0)
    fadeOut:SetDuration(500)
 
    -- begin to slide up after 2 seconds
    local translate = timeline:InsertAnimation(ANIMATION_TRANSLATE, control, AGT.saved.OnScreen.displayTicks*1000)
    translate:SetTranslateOffsets(offsetX, offsetY, offsetX, offsetY - 150)
    translate:SetDuration(500)
    translate:SetEasingFunction(ZO_EaseInQuadratic)
 
    -- reset the control's position once the animation stops
    timeline:SetHandler('OnStop', function()
        control:ClearAnchors()
        --control:SetAnchor(point, relativeTo, relativePoint, offsetX, offsetY)
		control:SetAnchor(CENTER, GuiRoot, TOPLEFT, AGT.saved.OnScreen.xOffset, AGT.saved.OnScreen.yOffset)
		AGT:doneAnimating()
    end)
 
    timeline:PlayFromStart()
end