-- initialize notifications
function AGT:initializeNotifications()
	-- create notification types
	AGT.note = {
		LEVEL_UP		= 0,	STATUS_CHANGE		= 1,		MOTD			= 2,
		HOUR_PLAYED		= 3,	ZONE_CHANGE			= 4,		TRYING			= 5,
		ERROR 			= 6,	ALERT				= 7,		SUCCESS			= 8,
		MOUNT			= 9,	CRAFT				= 10,		WISPER			= 11,
		GUILD			= 12,	OFFICER				= 13,		YELL			= 14,
		LOOT			= 15,
		vars = {
			msg		 	= {},	messages 	= 0,
			lastMsg		= 0},	suppression			= {}
	}
	AGT.isAnimating = false
end

-- main notification handling loop
function AGT:handelNotifications()
	if AGT.loaded then
		if not AGT.isAnimating then
			if (AGT.note.vars.messages > AGT.note.vars.lastMsg) then
				AGT.note.vars.lastMsg = AGT.note.vars.lastMsg + 1
				AGT.note.vars.hideAtTick = AGT.saved.OnScreen.displayTicks + AGT.tickCount
				AGT:displayNotification(unpack(AGT.note.vars.msg[AGT.note.vars.lastMsg]))
				AGT.note.vars.msg[AGT.note.vars.lastMsg] = nil -- clear up memory
			end
		end	
	end
end

--Start Animation
function AGT:startAnimating(msg)
	AGT.isAnimating = true
	AmiliousGuildToolsMessage:SetText(msg)
	AmiliousGuildTools:SetDimensions(400*AGT.saved.OnScreen.scale,250*AGT.saved.OnScreen.scale)
	timelineAnimation(AmiliousGuildTools)
end

-- animation Complete
function AGT:doneAnimating()
	AmiliousGuildToolsMessage:SetColor(unpack(AGT.saved.OnScreen.textColor))
	if(AGT.saved.OnScreen.isDisplayLocked)then
		AmiliousGuildToolsMessage:SetText("")
		AmiliousGuildTools:SetDimensions(0,0)
	else
		AmiliousGuildToolsMessage:SetText("AmiliousGuildTools")
		AmiliousGuildTools:SetDimensions(400*AGT.saved.OnScreen.scale,250*AGT.saved.OnScreen.scale)
		AmiliousGuildTools:SetAlpha(1)
	end
	AGT.isAnimating = false
end

-- show notification
function AGT:displayNotification(NType,Gid,Msg,chat,screen)
	local msgSettings = AGT:notificationCalculation(NType,Gid)
	local messageColor = "|c"..AGT.RGB_HEX(unpack(msgSettings[1]))
	local Message = Msg:gsub("%^c", messageColor)	
	if (Gid == nil) then
		Message = messageColor..Message.."|r"
		if not chat and msgSettings[5] then AGT:addToChat(Message) 	end
		if not screen and msgSettings[4] then AGT:startAnimating(Message) end
	else					-- is a guild message
		local guildColor = "|c"..AGT.RGB_HEX(unpack(AGT.saved.guild[Gid].color.default))
		Message = guildColor.."["..GetGuildName(AGT.data.guildID[Gid]).."]|r "..messageColor..Message.."|r"
		if not chat and msgSettings[5] then AGT:addToChat(Message) end
		if not screen and msgSettings[4] then AGT:startAnimating(Message) end
	end
	if AGT:isOn(msgSettings[4],screen) or AGT:isOn(msgSettings[5],chat) then
		if msgSettings[3] then PlaySound(msgSettings[2]) end
	end	
end

-- should this notification be suppressed
function AGT:notificationCalculation(NType,Gid)
	local MainColor 	= AGT.saved.OnScreen.textColor
	local Sound 		= AGT.sound["No_Sound"]
	local playSound		= AGT.saved.Settings.sounds
	local ShowOS 		= AGT.saved.OnScreen.isDisplayOn
	local ShowIC 		= true
	
	if(Gid == nil) then		
		if(NType == AGT.note.TRYING)then 
			MainColor 	= {1,1,0,1}		
			Sound 		= AGT.sound[AGT.saved.Sounds.trying]
			playSound 	= AGT.calulateValue(playSound,true)
			ShowOS 		= AGT.calulateValue(ShowOS,true)
			ShowIC 		= AGT.calulateValue(ShowIC,true)
		elseif(NType == AGT.note.ERROR)then 
			MainColor 	= {1,0,0,1}		
			Sound 		= AGT.sound[AGT.saved.Sounds.error]
			playSound 	= AGT.calulateValue(playSound,true)
			ShowOS 		= AGT.calulateValue(ShowOS,true)
			ShowIC 		= AGT.calulateValue(ShowIC,true)
		elseif(NType == AGT.note.SUCCESS)then 
			MainColor 	= {0,1,0,1}		
			Sound 		= AGT.sound[AGT.saved.Sounds.success]
			playSound 	= AGT.calulateValue(playSound,true)
			ShowOS 		= AGT.calulateValue(ShowOS,true)
			ShowIC 		= AGT.calulateValue(ShowIC,true)
		elseif(NType == AGT.note.MOUNT)then 
			MainColor 	= {1,0,0,1}		
			Sound 		= AGT.sound[AGT.saved.Sounds.mount]
			playSound 	= AGT.calulateValue(playSound,true)
			ShowOS 		= AGT.calulateValue(ShowOS,true)
			ShowIC 		= AGT.calulateValue(ShowIC,true)
		elseif(NType == AGT.note.HOUR_PLAYED)then 
			MainColor 	= {1,0,0,1}		
			Sound 		= AGT.sound[AGT.saved.Sounds.hour]
			playSound 	= AGT.calulateValue(playSound,true)
			ShowOS 		= AGT.calulateValue(ShowOS,true)
			ShowIC 		= AGT.calulateValue(ShowIC,true)
		elseif(NType == AGT.note.CRAFT)then 
			MainColor 	= {1,0,0,1}		
			Sound		= AGT.sound[AGT.saved.Sounds.craft]
			playSound 	= AGT.calulateValue(playSound,true)
			ShowOS 		= AGT.calulateValue(ShowOS,true)
			ShowIC 		= AGT.calulateValue(ShowIC,true)
		elseif(NType == AGT.note.WHISPER)then 
			MainColor 	= {0,1,1,1}		
			Sound		= AGT.sound[AGT.saved.Sounds.whisper]
			playSound 	= AGT.calulateValue(playSound,true)
			ShowOS 		= AGT.calulateValue(ShowOS,AGT.saved.note.whisper)
			ShowIC 		= false
		elseif(NType == AGT.note.YELL)then 
			MainColor 	= {1,0,0,1}		
			Sound		= AGT.sound[AGT.saved.Sounds.yell]
			playSound 	= AGT.calulateValue(playSound,true)
			ShowOS 		= AGT.calulateValue(ShowOS,AGT.saved.note.yell)
			ShowIC 		= false
		elseif(NType == AGT.note.LOOT)then
			MainColor	= AGT.saved.note.lootColor
			Sound 		= AGT.saved.Sounds.loot
			playSound 	= true
			ShowOS 		= AGT.saved.note.lootScreen
			ShowIC 		= AGT.saved.note.lootChat
		end
	else		
		ShowOS 			= AGT.calulateValue(ShowOS, AGT.saved.guild[Gid].showNotifications)
		ShowIC			= AGT.calulateValue(ShowIC, AGT.saved.guild[Gid].showOnScreen)		
		playSound 		= AGT.calulateValue(playSound,AGT.saved.guild[Gid].playSounds)
		if(NType == AGT.note.MOTD)then 
			MainColor 	= AGT.saved.guild[Gid].color.motd
			Sound 		= AGT.sound[AGT.saved.Sounds.motd]
			playSound 	= AGT.calulateValue(playSound,AGT.saved.guild[Gid].sound.motd)
			ShowOS 		= AGT.calulateValue(ShowOS,playSound,AGT.saved.guild[Gid].note.motd_OS)
			ShowIC 		= AGT.calulateValue(ShowIC,playSound,AGT.saved.guild[Gid].note.motd_CT)
		elseif(NType == AGT.note.STATUS_CHANGE)then 
			MainColor 	= AGT.saved.guild[Gid].color.status
			Sound 		= AGT.sound[AGT.saved.Sounds.status]
			playSound 	= AGT.calulateValue(playSound,AGT.saved.guild[Gid].sound.status)
			ShowOS 		= AGT.calulateValue(ShowOS,playSound,AGT.saved.guild[Gid].note.status_OS)
			ShowIC 		= AGT.calulateValue(ShowIC,playSound,AGT.saved.guild[Gid].note.status_CT)
		elseif(NType == AGT.note.LEVEL_UP)then 
			MainColor 	= AGT.saved.guild[Gid].color.level
			Sound 		= AGT.sound[AGT.saved.Sounds.level]
			playSound 	= AGT.calulateValue(playSound,AGT.saved.guild[Gid].sound.level)
			ShowOS 		= AGT.calulateValue(ShowOS,playSound,AGT.saved.guild[Gid].note.level_OS)
			ShowIC 		= AGT.calulateValue(ShowIC,playSound,AGT.saved.guild[Gid].note.level_CT)
		elseif(NType == AGT.note.ZONE_CHANGE)then 
			MainColor 	= AGT.saved.guild[Gid].color.zone
			Sound 		= AGT.sound[AGT.saved.Sounds.zone]
			playSound 	= AGT.calulateValue(playSound,AGT.saved.guild[Gid].sound.zone)
			ShowOS 		= AGT.calulateValue(ShowOS,playSound,AGT.saved.guild[Gid].note.zone_OS)
			ShowIC 		= AGT.calulateValue(ShowIC,playSound,AGT.saved.guild[Gid].note.zone_CT)
		elseif(NType == AGT.note.ALERT)then 
			MainColor 	= AGT.saved.guild[Gid].color.alert
			Sound 		= AGT.sound[AGT.saved.Sounds.alert]
			playSound 	= AGT.calulateValue(playSound,AGT.saved.guild[Gid].sound.alert)
			ShowOS 		= AGT.calulateValue(ShowOS,playSound,AGT.saved.guild[Gid].note.alert_OS)
			ShowIC 		= AGT.calulateValue(ShowIC,playSound,AGT.saved.guild[Gid].note.alert_CT)
		elseif(NType == AGT.note.GUILD)then 
			MainColor 	= AGT.saved.guild[Gid].color.default
			Sound 		= AGT.sound[AGT.saved.Sounds.guild]
			playSound 	= AGT.calulateValue(playSound,AGT.saved.guild[Gid].sound.guild)
			ShowOS 		= AGT.calulateValue(ShowOS,AGT.saved.guild[Gid].note.guild)
			ShowIC 		= false
		elseif(NType == AGT.note.OFFICER)then 
			MainColor 	= AGT.saved.guild[Gid].color.officer
			Sound 		= AGT.sound[AGT.saved.Sounds.officer]
			playSound 	= AGT.calulateValue(playSound,AGT.saved.guild[Gid].sound.officer)
			ShowOS 		= AGT.calulateValue(ShowOS,AGT.saved.guild[Gid].note.officer)
			ShowIC 		= false
		end	
	end
	return {MainColor, Sound, playSound, ShowOS, ShowIC}
end

-- add notification to notification queue
function AGT:addNotification(NType,Gid,Msg,chat,screen)
	chat 	= chat or false
	screen	= screen or false
	AGT.note.vars.messages = AGT.note.vars.messages + 1
	AGT.note.vars.msg[AGT.note.vars.messages] = {NType,Gid,Msg,chat,screen}
end

function AGT.calulateValue(option1,option2)
	if not option1 then return option1
	else return option2 end
end

-- check for suppression
function AGT:notificationSuppression(Msg)
	--check for message
	for k, v in pairs(AGT.note.suppression) do
		if(v[1] == Msg) then
			--suppress
			return true
		end
	end
	-- didn't exist so add it
	table.insert(AGT.note.suppression, {Msg,AGT.tickCount+1})
	return false
end

-- clear suppressions
function AGT:clearSuppressions()
	local removeList = {}
	-- find old suppressions
	for k, v in pairs(AGT.note.suppression) do
		if(v[2] <= AGT.tickCount) then
			table.remove(AGT.note.suppression, k)
		end
	end
end

-- calculate true
function AGT:isOn(val1,val2)
	if val1 then return true end
	if not val2 then return true end
	return false
end

function AGT:addToChat(msg)
	for temp = 1, #CHAT_SYSTEM.containers[1].windows do
		CHAT_SYSTEM.containers[1].windows[temp].buffer:AddMessage(msg)
	end
end